import { resolve } from "node:path";
import { environment, verifyRequiredVariables } from "@config";
import { logger } from "@creations.works/logger";
import { build } from "vite";
import type { PluginOption } from "vite";
import solidPlugin from "vite-plugin-solid";
import tsconfigPaths from "vite-tsconfig-paths";

verifyRequiredVariables();

function injectEnvPlugin(): PluginOption {
	return {
		name: "inject-env",
		transformIndexHtml(html) {
			return html
				.replace("__FQDN__", environment.fqdn)
				.replace("__BACKEND_URL__", environment.backendUrl);
		},
	};
}

await build({
	root: resolve("src"),
	publicDir: resolve("src/public"),
	plugins: [solidPlugin(), tsconfigPaths(), injectEnvPlugin()],
	build: {
		outDir: resolve("dist"),
		emptyOutDir: true,
		target: "esnext",
	},
});

logger.info("Production build complete.");
